import numpy as np
import matplotlib.pyplot as plt
import bin.functions as func
import seaborn as sns


def show_bfpar(src_delta,src_gauss,src_boxcar,bf):
    g = 3*src_delta
    b = 3*src_delta + 4*src_gauss

    if src_delta !=0:
        for i in range(src_delta):
            print('')
            print('      d{}-phi : {}'.format(i,bf[3*i]))
            print('      d{}-amp : {}'.format(i,bf[3*i+1]))
            print('      d{}-evpa: {}'.format(i,bf[3*i+2]))
                
    if src_gauss !=0:
        for i in range(src_gauss):
            print('')
            print('      g{}-phi : {}'.format(i,bf[4*i+g]))
            print('      g{}-amp : {}'.format(i,bf[4*i+1+g]))
            print('      g{}-evpa: {}'.format(i,bf[4*i+2+g]))
            print('      g{}-dphi: {}'.format(i,bf[4*i+3+g]))

    if src_boxcar !=0:
        for i in range(src_boxcar):
            print('')
            print('      t{}-phi : {}'.format(i,bf[4*i+b]))
            print('      t{}-amp : {}'.format(i,bf[4*i+1+b]))
            print('      t{}-evpa: {}'.format(i,bf[4*i+2+b]))
            print('      t{}-dphi: {}'.format(i,bf[4*i+3+b]))



def plot_spec(freq,lam2,q,u,q_err,u_err,src_delta,src_gauss,src_boxcar,bf):
    g = 3*src_delta
    b = 3*src_delta + 4*src_gauss
    q_rec = np.empty(len(freq),dtype=np.float64)
    u_rec = np.empty(len(freq),dtype=np.float64)

    for j in range(len(freq)):
        PI_sum = 0.
        if src_delta !=0:
            for i in range(src_delta):
                PI_sum = PI_sum + func.src_delta(lam2[j],bf[3*i],bf[3*i+1],bf[3*i+2])
                
        if src_gauss !=0:
            for i in range(src_gauss):
                PI_sum = PI_sum + func.src_gauss(lam2[j],bf[4*i+g],bf[4*i+1+g],bf[4*i+2+g],bf[4*i+3+g])

        if src_boxcar !=0:
            for i in range(src_boxcar):
                PI_sum = PI_sum + func.src_boxcar(lam2[j],bf[4*i+b],bf[4*i+1+b],bf[4*i+2+b],bf[4*i+3+b])
        q_rec[j] = PI_sum.real
        u_rec[j] = PI_sum.imag

    fig = plt.figure()
    
    ax1 = fig.add_subplot(2,1,1)
    plt.ylabel ('Q')
    ax1.errorbar(freq,q,q_err)
    ax1.plot(freq,q_rec)
    ax2 = fig.add_subplot(2,1,2)
    plt.ylabel ('U')
    plt.xlabel('Frequency [MHz]')
    ax2.errorbar(freq,u,u_err)
    ax2.plot(freq,u_rec)


def plot_1d(src_delta,src_gauss,src_boxcar,df):

    g = 3*src_delta
    b = 3*src_delta + 4*src_gauss

    if(src_delta != 0):
        for i in range(src_delta):
            fig = plt.figure()
            ax1 = fig.add_subplot(4,1,1)
            plt.title ('d'+str(i+1))
            plt.ylabel ('phi [rad/m/m]')
            ax1.plot(df[3*i])
            ax2 = fig.add_subplot(4,1,2)
            plt.ylabel ('amp')
            ax2.plot(df[3*i+1])
            ax3 = fig.add_subplot(4,1,3)
            plt.ylabel ('evpa [rad.]')
            ax3.plot(df[3*i+2])
            ax4 = fig.add_subplot(4,1,4)
            plt.ylabel ('chisq.')
            plt.xlabel('step')
            ax4.plot(df[len(df)-1])

    if(src_gauss != 0):
        for i in range(src_gauss):
            fig = plt.figure()
            ax1 = fig.add_subplot(5,1,1)
            plt.title ('g'+str(i+1))
            plt.ylabel ('phi [rad/m/m]')
            ax1.plot(df[4*i+g])
            ax2 = fig.add_subplot(5,1,2)
            plt.ylabel ('amp')
            ax2.plot(df[4*i+1+g])
            ax3 = fig.add_subplot(5,1,3)
            plt.ylabel ('evpa [rad.]')
            ax3.plot(df[4*i+2+g])
            ax4 = fig.add_subplot(5,1,4)
            plt.ylabel ('dphi [rad/m/m]')
            ax4.plot(df[4*i+3+g])
            ax5 = fig.add_subplot(5,1,5)
            plt.ylabel ('chisq.')
            plt.xlabel('step')
            ax5.plot(df[len(df)-1])

    if(src_boxcar != 0):
        for i in range(src_boxcar):
            fig = plt.figure()
            ax1 = fig.add_subplot(5,1,1)
            plt.title ('t'+str(i+1))
            plt.ylabel ('phi [rad/m/m]')
            ax1.plot(df[4*i+b])
            ax2 = fig.add_subplot(5,1,2)
            plt.ylabel ('amp')
            ax2.plot(df[4*i+1+b])
            ax3 = fig.add_subplot(5,1,3)
            plt.ylabel ('evpa [rad.]')
            ax3.plot(df[4*i+2+b])
            ax4 = fig.add_subplot(5,1,4)
            plt.ylabel ('dphi [rad/m/m]')
            plt.xlabel('step')
            ax4.plot(df[4*i+3+b])
            ax5 = fig.add_subplot(5,1,5)
            plt.ylabel ('chisq.')
            plt.xlabel('step')
            ax5.plot(df[len(df)-1])


#     print(df.shape)
#     print(df)

#     df = df.T

#     sns.set(style="white")


#     g = sns.PairGrid(df, diag_sharey=False)
#     g.map_lower(sns.kdeplot, cmap="Blues_d")
#     g.map_upper(plt.scatter)
#     g.map_diag(sns.kdeplot, lw=3)




# # def plot_2d():
        

