import numpy as np

def set_par_init(src_delta,src_gauss,src_boxcar):
    Npar = 3*src_delta + 4*src_gauss + 4*src_boxcar
    par  = np.empty([4,Npar],dtype=np.float64,order='F')
    peri = np.zeros([Npar],dtype=np.int32)

    g = 3*src_delta
    b = 3*src_delta + 4*src_gauss


    # init
    if src_delta != 0:
        for i in range(src_delta):
            par[0,3*i]     = 0.0 # phi
            par[0,3*i+1]   = 0.0 # amp
            par[0,3*i+2]   = 0.0 # evpa
    if src_gauss != 0:
        for i in range(src_gauss):
            par[0,4*i+g]   = 0.0 # phi
            par[0,4*i+1+g] = 0.0 # amp
            par[0,4*i+2+g] = 0.0 # evpa
            par[0,4*i+3+g] = 0.0 # dphi
    if src_boxcar != 0:
        for i in range(src_boxcar):
            par[0,4*i+b]   = 0.0 # phi
            par[0,4*i+1+b] = 0.0 # amp
            par[0,4*i+2+b] = 0.0 # evpa
            par[0,4*i+3+b] = 0.0 # dphi

    # stepsize
    if src_delta != 0:
        for i in range(src_delta):
            par[1,3*i]     = 10.0 # phi
            par[1,3*i+1]   = 1.0 # amp
            par[1,3*i+2]   = 0.1 # evpa
            # par[1,3*i]     = 0.0001 # phi
            # par[1,3*i+1]   = 0.0001 # amp
            # par[1,3*i+2]   = 0.0001 # evpa
    if src_gauss != 0:
        for i in range(src_gauss):
            par[1,4*i+g]   = 1.0 # phi
            par[1,4*i+1+g] = 1.0 # amp
            par[1,4*i+2+g] = 0.1 # evpa
            par[1,4*i+3+g] = 1.0 # dphi
    if src_boxcar != 0:
        for i in range(src_boxcar):
            par[1,4*i+b]   = 1.0 # phi
            par[1,4*i+1+b] = 1.0 # amp
            par[1,4*i+2+b] = 0.1 # evpa
            par[1,4*i+3+b] = 1.0 # dphi

    # minimum
    if src_delta != 0:
        for i in range(src_delta):
            par[2,3*i]     = -1.e4 # phi
            par[2,3*i+1]   =  0.0  # amp
            par[2,3*i+2]   =  0.0  # evpa
    if src_gauss != 0:
        for i in range(src_gauss):
            par[2,4*i+g]   = -1.e4 # phi
            par[2,4*i+1+g] =  0.0  # amp
            par[2,4*i+2+g] =  0.0  # evpa
            par[2,4*i+3+g] =  0.0  # dphi
    if src_boxcar != 0:
        for i in range(src_boxcar):
            par[2,4*i+b]   = -1.e4 # phi
            par[2,4*i+1+b] =  0.0  # amp
            par[2,4*i+2+b] =  0.0  # evpa
            par[2,4*i+3+b] =  0.0  # dphi

    # maximum
    if src_delta != 0:
        for i in range(src_delta):
            par[3,3*i]     = 1.e4 # phi
            par[3,3*i+1]   = 5.e2 # amp
            par[3,3*i+2]   = 0.0  # evpa
    if src_gauss != 0:
        for i in range(src_gauss):
            par[3,4*i+g]   = 1.e4 # phi
            par[3,4*i+1+g] = 5.e2 # amp
            par[3,4*i+2+g] = 0.0  # evpa
            par[3,4*i+3+g] = 5.e2 # dphi
    if src_boxcar != 0:
        for i in range(src_boxcar):
            par[3,4*i+b]   = 1.e4 # phi
            par[3,4*i+1+b] = 5.e2 # amp
            par[3,4*i+2+b] = 0.0  # evpa
            par[3,4*i+3+b] = 5.e2 # dphi

    # flag for periodic parameter
    if src_delta != 0:
        for i in range(src_delta):
            peri[3*i+2]   = 1
    if src_gauss != 0:
        for i in range(src_gauss):
            peri[4*i+2+g] = 1
    if src_boxcar != 0:
        for i in range(src_boxcar):
            peri[4*i+2+b] = 1

    return par, peri
